@@ -24,6 +24,9 @@ $finder = PhpCsFixer\Finder::create()
     ->notName('TestAttributeOnHookMethodsTest.php')
     // InvokableConstraintAndPipeOperatorTest.php uses PHP 8.5 syntax
     ->notName('InvokableConstraintAndPipeOperatorTest.php')
+    // FirstPartyClass.php and PhpDeprecationTest.php must not use declare(strict_types=1);
+    ->notPath('error-handler/_files/php-deprecation/src/FirstPartyClass.php')
+    ->notPath('error-handler/_files/php-deprecation/tests/PhpDeprecationTest.php')
     ->notName('*.phpt');
 
 $config = new PhpCsFixer\Config;
