@@ -9,8 +9,6 @@
  */
 namespace PHPUnit\Event\TestData;
 
-use function assert;
-use function count;
 use Iterator;
 
 /**
@@ -42,7 +40,7 @@ final class TestDataCollectionIterator implements Iterator
 
     public function valid(): bool
     {
-        return $this->position < count($this->data);
+        return isset($this->data[$this->position]);
     }
 
     /**
@@ -55,8 +53,6 @@ final class TestDataCollectionIterator implements Iterator
 
     public function current(): TestData
     {
-        assert(isset($this->data[$this->position]));
-
         return $this->data[$this->position];
     }
 
