@@ -27,11 +27,10 @@ final readonly class ExcludeStaticPropertyFromBackup extends Metadata
     private string $propertyName;
 
     /**
-     * @param int<0, 1>        $level
      * @param class-string     $className
      * @param non-empty-string $propertyName
      */
-    protected function __construct(int $level, string $className, string $propertyName)
+    protected function __construct(Level $level, string $className, string $propertyName)
     {
         parent::__construct($level);
 
