@@ -22,10 +22,9 @@ final readonly class TestDox extends Metadata
     private string $text;
 
     /**
-     * @param int<0, 1>        $level
      * @param non-empty-string $text
      */
-    protected function __construct(int $level, string $text)
+    protected function __construct(Level $level, string $text)
     {
         parent::__construct($level);
 
