@@ -35,6 +35,7 @@ use function restore_error_handler;
 use function set_error_handler;
 use function sprintf;
 use PHPUnit\Event;
+use PHPUnit\Event\Code\IssueTrigger\Code;
 use PHPUnit\Event\Code\IssueTrigger\IssueTrigger;
 use PHPUnit\Event\Code\NoTestCaseObjectOnCallStackException;
 use PHPUnit\Event\Code\TestMethod;
@@ -54,10 +55,11 @@ use PHPUnit\Util\ExcludeList;
  */
 final class ErrorHandler
 {
-    private const int UNHANDLEABLE_LEVELS     = E_ERROR | E_PARSE | E_CORE_ERROR | E_CORE_WARNING | E_COMPILE_ERROR | E_COMPILE_WARNING;
-    private const int INSUPPRESSIBLE_LEVELS   = E_ERROR | E_PARSE | E_CORE_ERROR | E_COMPILE_ERROR | E_USER_ERROR | E_RECOVERABLE_ERROR;
-    private static ?self $instance            = null;
-    private ?Baseline $baseline               = null;
+    private const int UNHANDLEABLE_LEVELS   = E_ERROR | E_PARSE | E_CORE_ERROR | E_CORE_WARNING | E_COMPILE_ERROR | E_COMPILE_WARNING;
+    private const int INSUPPRESSIBLE_LEVELS = E_ERROR | E_PARSE | E_CORE_ERROR | E_COMPILE_ERROR | E_USER_ERROR | E_RECOVERABLE_ERROR;
+    private static ?self $instance          = null;
+    private ?Baseline $baseline             = null;
+    private ExcludeList $excludeList;
     private bool $enabled                     = false;
     private ?int $originalErrorReportingLevel = null;
     private readonly bool $identifyIssueTrigger;
@@ -97,6 +99,7 @@ final class ErrorHandler
 
     private function __construct(bool $identifyIssueTrigger)
     {
+        $this->excludeList          = new ExcludeList;
         $this->identifyIssueTrigger = $identifyIssueTrigger;
     }
 
@@ -107,8 +110,10 @@ final class ErrorHandler
     {
         $suppressed = (error_reporting() & ~self::INSUPPRESSIBLE_LEVELS) === 0;
 
-        if ($suppressed && (new ExcludeList)->isExcluded($errorFile)) {
+        if ($suppressed && $this->excludeList->isExcluded($errorFile)) {
+            // @codeCoverageIgnoreStart
             return false;
+            // @codeCoverageIgnoreEnd
         }
 
         /**
@@ -117,7 +122,9 @@ final class ErrorHandler
          * @see https://github.com/sebastianbergmann/phpunit/issues/5956
          */
         if (defined('E_STRICT') && $errorNumber === 2048) {
+            // @codeCoverageIgnoreStart
             $errorNumber = E_NOTICE;
+            // @codeCoverageIgnoreEnd
         }
 
         $test = Event\Code\TestMethodBuilder::fromCallStack();
@@ -189,7 +196,7 @@ final class ErrorHandler
                     $suppressed,
                     $ignoredByBaseline,
                     $ignoredByTest,
-                    $this->trigger($test, false),
+                    $this->trigger($test, false, $errorFile),
                 );
 
                 break;
@@ -250,9 +257,7 @@ final class ErrorHandler
 
     public function enable(TestCase $test): void
     {
-        if ($this->enabled) {
-            return;
-        }
+        assert(!$this->enabled);
 
         $oldErrorHandler = set_error_handler($this);
 
@@ -321,52 +326,73 @@ final class ErrorHandler
         return $this->baseline->has(Issue::from($file, $line, null, $description));
     }
 
-    private function trigger(TestMethod $test, bool $filterTrigger): IssueTrigger
+    /**
+     * @param null|non-empty-string $errorFile
+     */
+    private function trigger(TestMethod $test, bool $isUserland, ?string $errorFile = null): IssueTrigger
     {
         if (!$this->identifyIssueTrigger) {
-            return IssueTrigger::unknown();
+            return IssueTrigger::from(null, null);
         }
 
-        $trace = $this->filteredStackTrace($filterTrigger);
+        if (!$isUserland) {
+            assert($errorFile !== null);
 
-        $triggeredInFirstPartyCode       = false;
-        $triggerCalledFromFirstPartyCode = false;
+            return IssueTrigger::from(Code::PHP, $this->categorizeFile($errorFile, $test));
+        }
+
+        $trace = $this->filteredStackTrace();
+
+        return $this->triggerForUserlandDeprecation($test, $trace);
+    }
+
+    /**
+     * @param list<array{file: string, line: int, class?: string, function?: string, type: string}> $trace
+     */
+    private function triggerForUserlandDeprecation(TestMethod $test, array $trace): IssueTrigger
+    {
+        $callee = null;
+        $caller = null;
 
         if (isset($trace[0]['file'])) {
-            if ($trace[0]['file'] === $test->file()) {
-                return IssueTrigger::test();
-            }
-
-            if (SourceFilter::instance()->includes($trace[0]['file'])) {
-                $triggeredInFirstPartyCode = true;
-            }
+            $callee = $this->categorizeFile($trace[0]['file'], $test);
         }
 
-        if (isset($trace[1]['file']) &&
-            ($trace[1]['file'] === $test->file() ||
-            SourceFilter::instance()->includes($trace[1]['file']))) {
-            $triggerCalledFromFirstPartyCode = true;
+        if (isset($trace[1]['file'])) {
+            $caller = $this->categorizeFile($trace[1]['file'], $test);
         }
 
-        if ($triggerCalledFromFirstPartyCode) {
-            if ($triggeredInFirstPartyCode) {
-                return IssueTrigger::self();
-            }
+        return IssueTrigger::from($callee, $caller);
+    }
 
-            return IssueTrigger::direct();
+    /**
+     * @param non-empty-string $file
+     */
+    private function categorizeFile(string $file, TestMethod $test): Code
+    {
+        if ($file === $test->file()) {
+            return Code::Test;
         }
 
-        return IssueTrigger::indirect();
+        if (SourceFilter::instance()->includes($file)) {
+            return Code::FirstParty;
+        }
+
+        if ($this->excludeList->isExcluded($file)) {
+            return Code::PHPUnit;
+        }
+
+        return Code::ThirdParty;
     }
 
     /**
      * @return list<array{file: string, line: int, class?: string, function?: string, type: string}>
      */
-    private function filteredStackTrace(bool $filterDeprecationTriggers): array
+    private function filteredStackTrace(): array
     {
         $trace = $this->errorStackTrace();
 
-        if ($this->deprecationTriggers === null || !$filterDeprecationTriggers) {
+        if ($this->deprecationTriggers === null) {
             return array_values($trace);
         }
 
@@ -461,8 +487,7 @@ final class ErrorHandler
      */
     private function stackTrace(): string
     {
-        $buffer      = '';
-        $excludeList = new ExcludeList(true);
+        $buffer = '';
 
         foreach ($this->errorStackTrace() as $frame) {
             /**
@@ -472,7 +497,7 @@ final class ErrorHandler
                 continue;
             }
 
-            if ($excludeList->isExcluded($frame['file'])) {
+            if ($this->excludeList->isExcluded($frame['file'])) {
                 continue;
             }
 
