@@ -144,8 +144,7 @@ final class ProgressPrinter
             return;
         }
 
-        if ($this->source->ignoreSelfDeprecations() &&
-            ($event->trigger()->isTest() || $event->trigger()->isSelf())) {
+        if ($this->source->ignoreSelfDeprecations() && $event->trigger()->isSelf()) {
             return;
         }
 
@@ -170,8 +169,7 @@ final class ProgressPrinter
             return;
         }
 
-        if ($this->source->ignoreSelfDeprecations() &&
-            ($event->trigger()->isTest() || $event->trigger()->isSelf())) {
+        if ($this->source->ignoreSelfDeprecations() && $event->trigger()->isSelf()) {
             return;
         }
 
