@@ -32,7 +32,7 @@ final class PhpDeprecationTriggeredTest extends AbstractEventTestCase
         $suppressed        = false;
         $ignoredByBaseline = false;
         $ignoredByTest     = false;
-        $trigger           = IssueTrigger::unknown();
+        $trigger           = IssueTrigger::from(null, null);
 
         $event = new PhpDeprecationTriggered(
             $telemetryInfo,
@@ -69,7 +69,7 @@ final class PhpDeprecationTriggeredTest extends AbstractEventTestCase
             false,
             true,
             false,
-            IssueTrigger::unknown(),
+            IssueTrigger::from(null, null),
         );
 
         $this->assertTrue($event->ignoredByBaseline());
@@ -87,7 +87,7 @@ final class PhpDeprecationTriggeredTest extends AbstractEventTestCase
             false,
             false,
             true,
-            IssueTrigger::unknown(),
+            IssueTrigger::from(null, null),
         );
 
         $this->assertTrue($event->ignoredByTest());
@@ -105,7 +105,7 @@ final class PhpDeprecationTriggeredTest extends AbstractEventTestCase
             true,
             false,
             false,
-            IssueTrigger::unknown(),
+            IssueTrigger::from(null, null),
         );
 
         $this->assertTrue($event->wasSuppressed());
