@@ -10,12 +10,15 @@
 namespace PHPUnit\Event\Code;
 
 use PHPUnit\Framework\Attributes\CoversClass;
+use PHPUnit\Framework\Attributes\Group;
 use PHPUnit\Framework\Attributes\Small;
 use PHPUnit\Framework\TestCase;
 
 #[CoversClass(Phpt::class)]
 #[CoversClass(Test::class)]
 #[Small]
+#[Group('event-system')]
+#[Group('event-system/value-objects')]
 final class PhptTest extends TestCase
 {
     public function testConstructorSetsValues(): void
