@@ -10,17 +10,21 @@
 namespace PHPUnit\TextUI\Configuration;
 
 use PHPUnit\Framework\Attributes\CoversClass;
+use PHPUnit\Framework\Attributes\Group;
 use PHPUnit\Framework\Attributes\Small;
 use PHPUnit\Framework\TestCase;
 
 #[CoversClass(File::class)]
 #[Small]
+#[Group('textui')]
+#[Group('textui/configuration')]
+#[Group('textui/configuration/value-objects')]
 final class FileTest extends TestCase
 {
     public function testHasPath(): void
     {
         $path = 'path';
 
-        $this->assertSame($path, (new File($path))->path());
+        $this->assertSame($path, new File($path)->path());
     }
 }
