@@ -10,31 +10,35 @@
 namespace PHPUnit\TextUI\Configuration;
 
 use PHPUnit\Framework\Attributes\CoversClass;
+use PHPUnit\Framework\Attributes\Group;
 use PHPUnit\Framework\Attributes\Small;
 use PHPUnit\Framework\TestCase;
 
 #[CoversClass(FilterDirectory::class)]
 #[Small]
+#[Group('textui')]
+#[Group('textui/configuration')]
+#[Group('textui/configuration/value-objects')]
 final class FilterDirectoryTest extends TestCase
 {
     public function testHasPath(): void
     {
         $path = 'path';
 
-        $this->assertSame($path, (new FilterDirectory($path, 'prefix', 'suffix'))->path());
+        $this->assertSame($path, new FilterDirectory($path, 'prefix', 'suffix')->path());
     }
 
     public function testHasPrefix(): void
     {
         $prefix = 'prefix';
 
-        $this->assertSame($prefix, (new FilterDirectory('path', $prefix, 'suffix'))->prefix());
+        $this->assertSame($prefix, new FilterDirectory('path', $prefix, 'suffix')->prefix());
     }
 
     public function testHasSuffix(): void
     {
         $suffix = 'suffix';
 
-        $this->assertSame($suffix, (new FilterDirectory('path', 'prefix', $suffix))->suffix());
+        $this->assertSame($suffix, new FilterDirectory('path', 'prefix', $suffix)->suffix());
     }
 }
