@@ -10,20 +10,24 @@
 namespace PHPUnit\TextUI\Configuration;
 
 use PHPUnit\Framework\Attributes\CoversClass;
+use PHPUnit\Framework\Attributes\Group;
 use PHPUnit\Framework\Attributes\Small;
 use PHPUnit\Framework\TestCase;
 
 #[CoversClass(IniSetting::class)]
 #[Small]
+#[Group('textui')]
+#[Group('textui/configuration')]
+#[Group('textui/configuration/value-objects')]
 final class IniSettingTest extends TestCase
 {
     public function testHasName(): void
     {
-        $this->assertSame('name', (new IniSetting('name', 'value'))->name());
+        $this->assertSame('name', new IniSetting('name', 'value')->name());
     }
 
     public function testHasValue(): void
     {
-        $this->assertSame('value', (new IniSetting('name', 'value'))->value());
+        $this->assertSame('value', new IniSetting('name', 'value')->value());
     }
 }
